app.factory('Util', ['$http','$rootScope','$location',function($http,$rootScope,$location){
    var getSemanaArray = function(abrev) {
        var s = {};
        if(abrev){
            s = {"1": "Dom", "2": "Seg", "3": "Ter", "4": "Qua", "5": "Qui", "6": "Sex", "7": "Sáb"};
        }else{
            s = {"1": "Domingo", "2": "Segunda-feira", "3": "Terça-feira", "4": "Quarta-feira", "5": "Quinta-feira", "6": "Sexta-feira", "7": "Sábado"};
        }            
        return s;
    };
    
    var random = function(r){
        return Math.floor((Math.random() * r) + 1)+"_"+new Date().getTime();
    };
    
    return{
        replaceAll: function(str, de, para){
            var pos = str.indexOf(de);
            while (pos > -1){
                        str = str.replace(de, para);
                        pos = str.indexOf(de);
                }
            return (str);
        },
        getSemanaTxt: function(dia, abrev) {
            if (dia) {
                var semana_arr = getSemanaArray(abrev);
                dia = parseInt(dia) + 1;
                return semana_arr[dia];
            }
        },
        /**
         * Retorna o endereço pelo cep
         * @param {string} cep
         * @param {boolean} notif_valid
         * @returns {undefined} retorna os dados ou false em caso de erro
         */
        getEnderecoViaCep: function(cep, notif_valid){ 
            var validacep = /^[0-9]{5}-?[0-9]{3}$/;
            if(!cep || cep.length!==8 || !validacep.test(cep)){
                if(notif_valid) alert('Atenção','Cep inválido');
                return false;
            }                           
            //Consultar webservice viacep.com.br
            $rootScope.loader = true;
            return $http.get("http://viacep.com.br/ws/"+ cep +"/json/?callback="); 
        },
        /**
         * Retornar o mês escrito em português
         * @param {int} m Mês entre 1 e 12
         * @param {boolean} abrev
         * @returns {meses_abrev|meses}
         */
        getTxtMes: function(m,abrev){
            var meses = {1 : "Janeiro", 2 : "Fevereiro", 3 : "Março", 4 : "Abril", 5 : "Maio", 6 : "Junho", 7 : "Julho", 8 : "Agosto", 9 : "Setembro", 10 : "Outubro", 11 : "Novembro", 12 : "Dezembro"};
            var meses_abrev = {1 : "Jan", 2 : "Fev", 3 : "Mar", 4 : "Abr", 5 : "Mai", 6 : "Jun", 7 : "Jul", 8 : "Ago", 9 : "Set", 10 : "Out", 11 : "Nov", 12 : "Dez"};
            
            m = parseInt(m);
            if(abrev) return meses_abrev[m];
            return meses[m];
        },
        goPag: function(p){
            $location.path(p);
        },
        isObjectEmpty: function(obj) {
            for(var prop in obj) {
                if(obj.hasOwnProperty(prop))
                    return false;
            }
            return true;
        },
        removeAcento: function(strToReplace) {
            str_acento = "áàãâäéèêëíìîïóòõôöúùûüçÁÀÃÂÄÉÈÊËÍÌÎÏÓÒÕÖÔÚÙÛÜÇ";
            str_sem_acento = "aaaaaeeeeiiiiooooouuuucAAAAAEEEEIIIIOOOOOUUUUC";
            var nova = "";
            for (var i = 0; i < strToReplace.length; i++) {
                if (str_acento.indexOf(strToReplace.charAt(i)) !== -1) {
                    nova += str_sem_acento.substr(str_acento.search(strToReplace.substr(i, 1)), 1);
                } else {
                    nova += strToReplace.substr(i, 1);
                }
            }
            return nova;
        },
        alertErrorMessage: function(data, status){
            if(status>0){
                if($rootScope.deviceready){
                    navigator.notification.alert(data.error.text, null, 'Erro');
                }else{
                    alert(data.error.text);
                }                
            }else{
                window.plugins.toast.showLongBottom('Requisição falhou! Verifique sua conexão com a internet.');
            }    
            return true;
       },
       parseDate: function(input){
            if(!input) return '';
            var formato_orig = input.indexOf('/') == 2 || input.indexOf('-') == 2 ? 'br' : 'am';
            var from = input.indexOf('/') > -1 ? input.split("/") : input.split("-");
            return formato_orig === 'br' ? new Date(from[2], from[1] - 1, from[0]) : new Date(from[0], from[1] - 1, from[2]);
        },
        clearDataString: function(data){
            if(!data) return '';
            var d = data;
            data = d ? d.replace(/-/g,'') : '';
                   
            if(!data) return '';
            var d = data.replace('/','');
            data = d.replace('/','');
            return data.substr(0,8);
        },
        formatDataString: function(d){
            d = this.clearDataString(d);
            return d ? d.substr(0,2) + "/" + d.substr(2,2) + "/" + d.substr(4,4) : '';
        },
        formatTelString: function(d){
            d = d ? d.replace('(','') : '';
            d = d ? d.replace(')','') : '';
            d = d ? d.replace('-','') : '';
            return d ? "(" + d.substr(0,2) + ") " + d.substr(2,4) + "-" + d.substr(6) : '';
        },
        formatCpfString: function(d){
            return d ? d.substr(0,3) + "." + d.substr(3,3) + "." + d.substr(6,3) + "-" + d.substr(9,2) : '';
        },
        formatCepString: function(d){
            return d ? d.substr(0,5) + "-" + d.substr(5,3) : '';
        },
       /**
        * Retorna um número randômico
        * @param {type} _r
        * @returns {Number}
        */
       random: function(_r){
           var r = _r ? _r : 1000;
           return random(r);
       },
       getHojeAM: function(){
            var today = new Date();
            var dd = today.getDate();
            var mm = today.getMonth()+1; //January is 0!
            var yyyy = today.getFullYear();

            if(dd<10) {
                dd='0'+dd;
            } 

            if(mm<10) {
                mm='0'+mm;
            } 

            return yyyy+"-"+mm+'-'+dd;
       }
    };
}]);

app.factory('bdAppService',['$rootScope', function($rootScope){
    var db_app = null;
    
    var conex = function(){
        if(db_app === null){
            //Conectar base de dados dbapp.sqlite
            try {
                
                if($rootScope.deviceready){
                    if (window.sqlitePlugin.openDatabase) {
                        db_app = window.sqlitePlugin.openDatabase({name: 'dbapp'});//Produção
                    } else {
                        if(!$rootScope.deviceready){
                            alert('Não suporta acesso a banco sqlite!');
                        }else{
                            navigator.notification.alert("Não suporta acesso a banco sqlite!", null, 'Erro');
                        }                        
                    }
                }else{
                    db_app = window.openDatabase('dbapp','1.0','dbapp',22222);//Testes                        
                }

                if (!db_app){
                    navigator.notification.alert("Falha ao abrir o banco de dados do app!", null, 'Erro');
                    return false;
                }else{
                    //CRIAR TABELAS SE NÃO EXISTIREM
                    db_app.transaction(function(tx){
                        //tx.executeSql('DROP TABLE IF EXISTS msgs');
                        tx.executeSql('CREATE TABLE IF NOT EXISTS download (dw_cod INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL UNIQUE, dw_nome VARCHAR(80) NOT NULL, dw_arq VARCHAR(60) NOT NULL, dw_ok INTEGER(1) DEFAULT 0 NOT NULL, dw_lix INTEGER(1) DEFAULT 0 NOT NULL, dw_datacreate DATETIME NOT NULL)');
                        tx.executeSql('CREATE TABLE IF NOT EXISTS msgs (id_local INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL UNIQUE, msg_ig_cod INTEGER(11) NOT NULL, msg_post_us_cod INTEGER(11) NOT NULL, msg_msgtxt TEXT NULL, msg_arq VARCHAR(90) NULL, msg_midia INTEGER(2) DEFAULT 0 NOT NULL, mime VARCHAR(12) NULL, image_uri TEXT NULL, tipo_cap_foto VARCHAR(10) NULL, st_envio INTEGER(1) DEFAULT 0 NOT NULL, msg_datacreate DATETIME DEFAULT CURRENT_TIMESTAMP NOT NULL)');
                        tx.executeSql('CREATE TABLE IF NOT EXISTS cons_consolidar (cs_cod INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL UNIQUE, cs_ig_cod INTEGER(11), cs_consolidador_cod INTEGER(11), cs_nome VARCHAR(80) NOT NULL, cs_tel VARCHAR(15) NOT NULL, cs_bairro VARCHAR(60), cs_st INTEGER(1) DEFAULT 0 NOT NULL, cs_data DATETIME NOT NULL)');
                    }, function(err){
                        if(!$rootScope.deviceready){
                            alert("Error processing SQL: " + err.code + " - "+err.message);
                        }else{
                            navigator.notification.alert("Error processing SQL: " + err.code + " - "+err.message, null, 'Erro');
                        }

                    }, function(){//Success
                        //                         
                    });
                    return db_app;
                }
                        
            } catch(err) {}
        }else{
            return db_app;
        }
    };
    
    return {
        conex: function(){
            return conex();
        },
        errorDB: function(error) {
            if(!$rootScope.deviceready){
                alert("Erro ao processar o SQL: " + error.code + " - "+error.message, null, 'Erro');
            }else{
                navigator.notification.alert("Erro ao processar o SQL: " + error.code + " - "+error.message, null, 'Erro');
            }
        }
    };
}]);

app.factory('UtilData', ['$http','$rootScope','$location',function($http,$rootScope,$location){
    var convertStringForData = function(_data) {
        var tp = "am";
        var f = _data.substr(0, 4);//Pega os 4 primeiros caracteres
        if(f.indexOf("/") > -1 || f.indexOf("-") > -1){//Se for BR
            tp = "br";
        }

        var valid;
        var data_am;

        if(tp === "br"){
            valid = validarDataBr(_data);
        }else{
            valid = validarDataAm(_data);
        }

        if(valid){
            if(tp === "br"){
                data_am = _data.substr(6, 4) + "-" + _data.substr(3, 2) + "-" + _data.substr(0, 2);
            }else{
                data_am = _data.substr(0, 4) + "-" + _data.substr(5, 2) + "-" + _data.substr(8, 2);
            }        
            return new Date(data_am);
        }else{
            return "";
        }        
    };
    var validarDataBr = function(data) {//dd/mm/aaaa
        day = data.substr(0, 2);
        month = data.substr(3, 2);
        year = data.substr(6, 4);
        return validarData(day, month, year);
    };
    var validarDataAm = function(data) {//aaaa-mm-dia
        day = data.substr(8, 2);
        month = data.substr(5, 2);
        year = data.substr(0, 4);
        return validarData(day, month, year);
    };
    var validarData = function(day, month, year) {

        if ((month == 01) || (month == 03) || (month == 05) || (month == 07) || (month == 08) || (month == 10) || (month == 12)) {//mes com 31 dias
            if ((day < 01) || (day > 31)) {
                //alert('invalid date');
                return false;
            }
        } else

        if ((month == 04) || (month == 06) || (month == 09) || (month == 11)) {//mes com 30 dias
            if ((day < 01) || (day > 30)) {
                //alert('invalid date');
                return false;
            }
        } else

        if ((month == 02)) {//February and leap year
            if ((year % 4 == 0) && ((year % 100 != 0) || (year % 400 == 0))) {
                if ((day < 01) || (day > 29)) {
                    //alert('invalid date');
                    return false;
                }
            } else {
                if ((day < 01) || (day > 28)) {
                    //alert('invalid date');
                    return false;
                }
            }
        }

        if(month > 12){
            return false;
        }

        return true;
    };
    
    var convertDataForBr = function(_data){
        if(!_data) return "";
        var valid = validarDataAm(_data);
        if(valid){
            return _data.substr(8, 2) + "/" + _data.substr(5, 2) + "/" + _data.substr(0, 4);
        }else{
            return "";
        }        
    };
    var convertDataForAm = function(_data){
        if(!_data) return "";
        var valid = validarDataBr(_data);
        if(valid){
            return _data.substr(6, 4) + "-" + _data.substr(3, 2) + "-" + _data.substr(0, 2);
        }else{
            return "";
        }        
    };
    
    return{ 
        convertStringForData: function(_data) {
            return convertStringForData(_data);  
        },
        validarDataBr: function(data) {//dd/mm/aaaa
            return validarDataBr(data);
        },
        validarDataAm: function(data) {//aaaa-mm-dia
            return validarDataAm(data);
        },
        validarData: function(day, month, year) {
            return validarData(day, month, year);
        },
        convertDataForBr: function(_data){
            return convertDataForBr(_data);
        },
        convertDataForAm: function(_data){
            return convertDataForAm(_data);
        }
    };
}]);


app.factory('http', ['$http', '$location', '$rootScope', function($http, $location, $rootScope){
    return{
       get: function(url){
          return $http.get(url);
       },
       post: function(url, params){
          params = params ? params : null;
          return $http({
                    url: url,
                    method: 'POST',
                    //data: $.param(params),
                    data: params,
                    headers: {'Content-Type': 'application/x-www-form-urlencoded'},
                    timeout: 20000
                });
       }
    };
 }]);
 
 
 
 
 ///////// GEO LOCALIZAÇÃO DO DISPOSITIVO ///////////////////////////// 
 app.factory('geo', function(){
     var obj = {};
     var initializeMap = function() {
        //$scope.geoCapLocalizDispositParaIdentificIgreja();
     };
     
     var startGeoLocalizarEndereco = function(callback){
        var options = {timeout: 30 * 1000, enableHighAccuracy: false};
        geoCurrentPositionIdParaIdentificIgreja = navigator.geolocation.getCurrentPosition(function (position) {
            geoCurrentPositionIdParaIdentificIgreja = "";

            var lat = position.coords.latitude;
            var lng = position.coords.longitude;

            var latitude = parseFloat(lat);
            var longitude = parseFloat(lng);
            var latLng = new google.maps.LatLng(latitude, longitude);

            var geocoder = new google.maps.Geocoder();
            geocoder.geocode({'latLng': latLng},
            function (results, status) {
                if (status === google.maps.GeocoderStatus.OK) {
                    if (results[0]) {
                        var r = results[0].formatted_address;
                        //var r_arr = r.split(',');

                        for (i = 0; i < results[0].address_components.length; ++i) {
                            var c = results[0].address_components[i];
                            if (c.types.indexOf("route") > -1) {
                                obj.endereco_short_name = c.short_name;
                                obj.endereco_long_name = c.long_name;
                            }
                            if (c.types.indexOf("street_number") > -1) {
                                obj.street_number_short_name = c.short_name;
                                obj.street_number_long_name = c.long_name;
                            }
                            if (c.types.indexOf("neighborhood") > -1) {
                                obj.bairro_short_name = c.short_name;
                                obj.bairro_long_name = c.long_name;
                            }
                            if (c.types.indexOf("administrative_area_level_1") > -1) {
                                obj.uf_short_name = c.short_name;
                                obj.uf_long_name = c.long_name;
                            }
                            if (c.types.indexOf("administrative_area_level_2") > -1) {
                                obj.cidade_short_name = c.short_name;
                                obj.cidade_long_name = c.long_name;
                            }
                            if (c.types.indexOf("country") > -1) {
                                obj.pais_short_name = c.short_name;
                                obj.pais_long_name = c.long_name;
                            }
                            if (c.types.indexOf("postal_code") > -1) {
                                obj.cep_short_name = c.short_name;
                                obj.cep_long_name = c.long_name;
                            }
                            obj.endereco_completo = results[0].formatted_address;                                
                        }
                        callback(obj);
                    }
                    else {
                        callback(obj);
                        //$("#address").html("No results");
                    }
                }
                else {
                    callback(obj);
                    //$("#address").html(status);
                }
            });
        }, function (error) {
            callback(null);
//            var erro_txt = "";
//            if (error.code === PositionError.PERMISSION_DENIED) {
//                erro_txt = "Erro de permissão: O seu dispositivo está configurado para não permitir a recuperação da posição do dispositivo. Altere as configurações do aparelho e tente de novo.";
//            } else if (error.code === PositionError.POSITION_UNAVAILABLE) {
//                erro_txt = "O dispositivo não foi capaz de recuperar a posição. Em geral, isso significa que o dispositivo não está conectado a uma rede ou não pode obter uma correção por satélite. Verifique se o seu GPS está ativo.";
//            } else if (error.code === PositionError.TIMEOUT) {
//                erro_txt = "Tempo limite excedito.";
//            }
//
//            navigator.notification.alert(erro_txt + ' - Erro nº: ' + error.code, null, 'Erro na captura');
        }, options);
    };
        
     return {
         geoLocalizEnderecoDispositivo: function(callback) {
            if (typeof google === 'object' && typeof google.maps === 'object') {//Verifica se já foi carregado
                startGeoLocalizarEndereco(function(addr){
                    callback(addr);  
                });
            }else{
                $.getScript("http://maps.google.com/maps/api/js?key=AIzaSyCMjyhWHIgrT97eiPaZbudX84zT_7L7bsk&sensor=true&callback=initializeMap")
                .done(function (script, textStatus) {   
                    setTimeout(function(){
                        //alert("Google map script loaded successfully");
                        startGeoLocalizarEndereco(function(addr){
                            callback(addr);  
                            count_map_google_loader = 0;
                        });                            
                    }, 1000);                   
                })
                .fail(function (jqxhr, settings, ex) {
                    callback(null);
                    //alert("Could not load Google Map script: " + jqxhr);
                    //window.plugins.toast.showLongTop('Não foi possível carregar o mapa! Verifique sua conexão com a internet.');
                });
            }                
        }
     };
 });


 
 
// app.factory('pagination', ['notific',function(notific){
//    var pg_c = {pg: 1, pg_max: 1, regporpag: 15, count_row: 0, pg_modo_edit: false, pg_edit: 1};
//    return{
//       getPg: function(){
//            return pg_c;
//       },
//       cancelPgEdit: function(pag){
//            pag.pg_modo_edit = false; 
//            pag.pg_edit = pag.pg;
//       },
//       setPg: function(pag,_pg){
//            pag.pg_modo_edit = false;
//            if(pag.pg_max>0 && _pg > pag.pg_max){
//                pag.pg_edit = pag.pg;
//                notific.notific_simple('warning','Página inválida');
//                return false;
//            }else{
//                _pg = (_pg === undefined || _pg <= 0) ? 1 : _pg;
//            }
//            pag.pg = pag.pg_edit = _pg;        
//
//            return _pg;
//       }
//    };
// }]);
// 
// app.factory('paginationMesAno', ['Util','notific',function(Util,notific){
//    var d = new Date();
//    var _mes = d.getMonth()+1;
//    var _ano = d.getFullYear();
//    var pg_c = {mes: _mes, ano: _ano, mes_ano_txt: Util.getTxtMes(_mes,true)+"/"+_ano};
//    
//    return{
//       getPg: function(){
//            return pg_c;
//       },
//       setMesAnoTxt: function(){
//             pg_c.mes_ano_txt = Util.getTxtMes(pg_c.mes,true)+"/"+pg_c.ano;
//       },
//       cancelPgEdit: function(pag){
//            pag.pg_modo_edit = false; 
//            pag.pg_edit = pag.pg;
//       },
//       mesAntPg: function(){            
//            this.acrescUmMesPg(-1);
//       },
//       proxMesPg: function(){            
//            this.acrescUmMesPg(1);            
//       },
//       acrescUmMesPg: function(dc){
//            var data = pg_c.ano+"-"+pg_c.mes+"-"+01;
//            var now = new Date(data);  
//            var month = now.getMonth();
//            var ac = now.setMonth(month + dc);
//            var pm = $.format.date(ac,'yyyy-MM-dd');
//            pg_c.mes = pm.substr(5,2);
//            pg_c.ano = parseInt(pm.substr(0,4));  
//            this.setMesAnoTxt();
//       },
//       verifPg: function(){             
//           if(!angular.isNumber(pg_c.ano)){
//               var now = new Date();
//               pg_c.ano = parseInt(now.getFullYear());
//               this.setMesAnoTxt();
//               return false;
//           }
//           return true;
//       }
//    };
// }]);



app.factory('biblia_velho_testamento_arr', function(){
    return [
        {id: 1,  liv: 'Gênesis'},
        {id: 2,  liv: 'Êxodo'},
        {id: 3,  liv: 'Levítico'},
        {id: 4,  liv: 'Números'},
        {id: 5,  liv: 'Deuteronômio'},
        {id: 6,  liv: 'Josué'},
        {id: 7,  liv: 'Juízes'},
        {id: 8,  liv: 'Rute'},
        {id: 9,  liv: '1 Samuel'},
        {id: 10, liv: '2 Samuel'},
        {id: 11, liv: '1 Reis'},
        {id: 12, liv: '2 Reis'},
        {id: 13, liv: '1 Crônicas'},
        {id: 14, liv: '2 Crônicas'},
        {id: 15, liv: 'Esdras'},
        {id: 16, liv: 'Neemias'},
        {id: 17, liv: 'Ester'},
        {id: 18, liv: 'Jó'},
        {id: 19, liv: 'Salmos'},
        {id: 20, liv: 'Provérbios'},
        {id: 21, liv: 'Eclesiastes'},
        {id: 22, liv: 'Cantares de Salomão'},
        {id: 23, liv: 'Isaías'},
        {id: 24, liv: 'Jeremias'},
        {id: 25, liv: 'Lamentações de jeremias'},
        {id: 26, liv: 'Ezequiel'},
        {id: 27, liv: 'Daniel'},
        {id: 28, liv: 'Oséias'},
        {id: 29, liv: 'Joel'},
        {id: 30, liv: 'Amós'},
        {id: 31, liv: 'Obadias'},
        {id: 32, liv: 'Jonas'},
        {id: 33, liv: 'Miquéias'},
        {id: 34, liv: 'Naum'},
        {id: 35, liv: 'Habacuque'},
        {id: 36, liv: 'Sofonias'},
        {id: 37, liv: 'Ageu'},
        {id: 38, liv: 'Zacarias'},
        {id: 39, liv: 'Malaquias'}  
    ];
});

app.factory('biblia_novo_testamento_arr', function(){
    return [
        {id: 40,  liv: 'Mateus'},
        {id: 41,  liv: 'Marcos'},
        {id: 42,  liv: 'Lucas'},
        {id: 43,  liv: 'João'},
        {id: 44,  liv: 'Atos dos apóstolos'},
        {id: 45,  liv: 'Romanos'},
        {id: 46,  liv: '1 Coríntios'},
        {id: 47,  liv: '2 Coríntios'},
        {id: 48,  liv: 'Gálatas'},
        {id: 49,  liv: 'Efésios'},
        {id: 50,  liv: 'Filipenses'},
        {id: 51,  liv: 'Colossenses'},
        {id: 52,  liv: '1 Tessalonicenses'},
        {id: 53,  liv: '2 Tessalonicenses'},
        {id: 54,  liv: '1 Timóteo'},
        {id: 55,  liv: '2 Timóteo'},
        {id: 56,  liv: 'Tito'},
        {id: 57,  liv: 'Filemom'},
        {id: 58,  liv: 'Hebreus'},
        {id: 59,  liv: 'Tiago'},
        {id: 60,  liv: '1 Pedro'},
        {id: 61,  liv: '2 Pedro'},
        {id: 62,  liv: '1 João'},
        {id: 63,  liv: '2 João'},
        {id: 64,  liv: '3 João'},
        {id: 65,  liv: 'Judas'},
        {id: 66,  liv: 'Apocalipse'}
    ];
});

app.factory('rede_celulas_arr', function(){
    return [
        {id: 1, nome: 'Homens'},
        {id: 2, nome: 'Mulheres'},
        {id: 3, nome: 'Rapazes'},
        {id: 4, nome: 'Jovens casados'},
        {id: 5, nome: 'Moças'},
        {id: 6, nome: 'Crianças'},
        {id: 7, nome: 'Jovens'},
        {id: 8, nome: 'Adolescentes'},
        {id: 9, nome: 'Casados'},
        {id: 10, nome: 'Juniores'}
    ];
});

app.factory('uf_arr', function(){
    return [
        {cod_ibge: 11, sigla: 'RO', nome: 'Rondônia'},
        {cod_ibge: 12, sigla: 'AC', nome: 'Acre'},
        {cod_ibge: 13, sigla: 'AM', nome: 'Amazonas'},
        {cod_ibge: 14, sigla: 'RR', nome: 'Roraima'},
        {cod_ibge: 15, sigla: 'PA', nome: 'Pará'},
        {cod_ibge: 16, sigla: 'AP', nome: 'Amapá'},
        {cod_ibge: 17, sigla: 'TO', nome: 'Tocantins'},
        {cod_ibge: 21, sigla: 'MA', nome: 'Maranhão'},
        {cod_ibge: 22, sigla: 'PI', nome: 'Piauí'},
        {cod_ibge: 23, sigla: 'CE', nome: 'Ceará'},
        {cod_ibge: 24, sigla: 'RN', nome: 'Rio Grande do Norte'},
        {cod_ibge: 25, sigla: 'PB', nome: 'Paraíba'},
        {cod_ibge: 26, sigla: 'PE', nome: 'Pernambuco'},
        {cod_ibge: 27, sigla: 'AL', nome: 'Alagoas'},
        {cod_ibge: 28, sigla: 'SE', nome: 'Sergipe'},
        {cod_ibge: 29, sigla: 'BA', nome: 'Bahia'},
        {cod_ibge: 31, sigla: 'MG', nome: 'Minas Gerais'},
        {cod_ibge: 32, sigla: 'ES', nome: 'Espírito Santo'},
        {cod_ibge: 33, sigla: 'RJ', nome: 'Rio de Janeiro'},
        {cod_ibge: 35, sigla: 'SP', nome: 'São Paulo'},
        {cod_ibge: 41, sigla: 'PR', nome: 'Paraná'},
        {cod_ibge: 42, sigla: 'SC', nome: 'Santa Catarina'},
        {cod_ibge: 43, sigla: 'RS', nome: 'Rio Grande do Sul'},
        {cod_ibge: 50, sigla: 'MS', nome: 'Mato Grosso do Sul'},
        {cod_ibge: 51, sigla: 'MT', nome: 'Mato Grosso'},
        {cod_ibge: 52, sigla: 'GO', nome: 'Goiás'},
        {cod_ibge: 53, sigla: 'DF', nome: 'Distrito Federal'}
    ];
});
